@@ -1,9 +1,5 @@
 from typing import Dict
 
-from tabledbmapper.engine import TemplateEngine
-from tabledbmapper.manager.manager import Manager
-from tabledbmapper.manager.xml_config import parse_config_from_string
-
 # noinspection SpellCheckingInspection
 _table_xml = """
 <xml>
@@ -24,7 +20,7 @@ _table_xml = """
         </value>
     </sql>
     <sql>
-        <key>GetRecord</key>
+        <key>GetModel</key>
         <value>
             SELECT
                 TABLE_NAME, ENGINE, TABLE_COLLATION, TABLE_COMMENT, IFNULL(AUTO_INCREMENT, -1)
@@ -110,77 +106,60 @@ _key_xml = """
 </xml>
 """
 
+DatabaseInfoManager = Dict
 DataBaseInfo = Dict
 
 
-class DBInfo:
+# noinspection SpellCheckingInspection
+def get_db_info(database_info_manager: DatabaseInfoManager, database_name: str) -> DataBaseInfo:
     """
-    A tool class for obtaining database information by querying mysql.
-    information_ Schema table. Get database table structure information
+    Get database information
+    :param database_info_manager: the database info manager
+    :param database_name: Database name
+    :return: database information
     """
+    return __get_info(database_info_manager, "GetList", {"data_base_name": database_name})
 
-    def __init__(self, template_engine: TemplateEngine, database_name: str):
-        # Read profile
-        table_config = parse_config_from_string(_table_xml)
-        column_config = parse_config_from_string(_column_xml)
-        index_config = parse_config_from_string(_index_xml)
-        key_config = parse_config_from_string(_key_xml)
 
-        # builder manager
-        self.table_manager = Manager(template_engine, table_config)
-        self.column_manager = Manager(template_engine, column_config)
-        self.index_manager = Manager(template_engine, index_config)
-        self.key_manager = Manager(template_engine, key_config)
+# noinspection SpellCheckingInspection
+def get_table_info(database_info_manager: DatabaseInfoManager, database_name: str, table_name: str) -> DataBaseInfo:
+    """
+    Get database information
+    :param database_info_manager: the database info manager
+    :param database_name: Database name
+    :param table_name: database table name
+    :return: database information
+    """
+    return __get_info(database_info_manager, "GetModel", {"data_base_name": database_name, "table_name": table_name})
 
-        # cache database name
-        self.database_name = database_name
 
-    def get_db_info(self) -> DataBaseInfo:
-        """
-        Get database information
-        :return: database information
-        """
-        table_map = {}
-        # Query table structure information
-        tables = self.table_manager.query("GetList", {"data_base_name": self.database_name})
-        for table in tables:
-            table["columns"] = self.column_manager.query(
-                "GetList",
-                {"data_base_name": self.database_name, "table_name": table["Name"]}
-            )
-            table["indexs"] = self.index_manager.query(
-                "GetList",
-                {"data_base_name": self.database_name, "table_name": table["Name"]}
-            )
-            table["keys"] = self.key_manager.query(
-                "GetList",
-                {"data_base_name": self.database_name, "table_name": table["Name"]}
-            )
-            table_map[table["Name"]] = table
-        return table_map
+def __get_info(database_info_manager: DatabaseInfoManager, query_name: str, query_param: dict) -> DataBaseInfo:
+    """
+    Get database information
+    :param database_info_manager: the database info manager
+    :param query_name: table manager query name
+    :param query_param: table manager query name && query param
+    :return: database information
+    """
+    # builder manager
+    table_manager = database_info_manager["table_manager"]
+    column_manager = database_info_manager["column_manager"]
+    index_manager = database_info_manager["index_manager"]
+    key_manager = database_info_manager["key_manager"]
 
-    def get_table_info(self, table_name: str) -> DataBaseInfo:
-        """
-        Get table information
-        :return: table information
-        """
-        # Query table structure information
-        tables = self.table_manager.query("GetRecord", {
-            "data_base_name": self.database_name,
-            "table_name": table_name
-        })
-        # The indication is specified here, so only one record will be returned
-        table = tables[0]
-        table["columns"] = self.column_manager.query(
+    # Query table structure information
+    tables = table_manager.query(query_name, query_param)
+    for table in tables:
+        table["columns"] = column_manager.query(
             "GetList",
-            {"data_base_name": self.database_name, "table_name": table["Name"]}
+            {"data_base_name": query_param["data_base_name"], "table_name": table["Name"]}
         )
-        table["indexs"] = self.index_manager.query(
+        table["indexs"] = index_manager.query(
             "GetList",
-            {"data_base_name": self.database_name, "table_name": table["Name"]}
+            {"data_base_name": query_param["data_base_name"], "table_name": table["Name"]}
         )
-        table["keys"] = self.key_manager.query(
+        table["keys"] = key_manager.query(
             "GetList",
-            {"data_base_name": self.database_name, "table_name": table["Name"]}
+            {"data_base_name": query_param["data_base_name"], "table_name": table["Name"]}
         )
-        return table
+    return {"Name": query_param["data_base_name"], "tables": tables}
